@@ -250,7 +250,7 @@ create_apple_menu (GtkosxApplication *self, GtkWidget *toplevel)
   /* Translators: This is the Services menu item for the "Apple" menu. */
   NSString *title = [NSString stringWithUTF8String: _("Services")];
   NSMenu *menuServices = [[[NSMenu alloc] initWithTitle: title] autorelease];
-  NSString *appname = get_application_name ();
+  const char *appname = [get_application_name () UTF8String];
   GClosure *hide_closure, *hide_others_closure;
   GtkAccelGroup *accel_group = gtk_accel_group_new ();
   gtk_window_add_accel_group (GTK_WINDOW (toplevel), accel_group);
@@ -852,13 +852,40 @@ gtkosx_application_insert_app_menu_item (GtkosxApplication* self,
                                          gint index)
 {
   gtk_widget_set_visible (item, TRUE);
+  /* For backwards compatibility, the 0 index item is forced to be About. */
   if (index == 0)
-    return;
-
+    {
+      const gchar * app_name = [get_application_name () UTF8String];
+      gtk_menu_item_set_label (GTK_MENU_ITEM (item), g_strdup_printf (_("About %s"), app_name));
+    }
   cocoa_menu_item_add_item ([[[NSApp mainMenu] itemAtIndex: 0] submenu],
                             item, index);
 }
 
+/**
+ * gtkosx_application_set_about_item
+ * @self: The application object
+ * @item: The about menu item
+ *
+ * Sets the designated menu item as the "About <appname>", the first
+ * one on the App Menu. We take a GtkMenuItem* because it's less work
+ * for app developers than unwrapping a GtkAction for us to wrap in an
+ * NSAction.
+ */
+
+void
+gtkosx_application_set_about_item (GtkosxApplication* self,
+                                        GtkWidget* item)
+{
+  const static int about_index = 0;
+  const gchar * app_name = [get_application_name () UTF8String];
+  /* Translators: This is the "About foo" menu item at the top of the App menu. */
+  gtk_menu_item_set_label (GTK_MENU_ITEM (item), g_strdup_printf (_("About %s"), app_name));
+  cocoa_menu_item_add_item ([[[NSApp mainMenu] itemAtIndex: 0] submenu],
+                            item, about_index);
+}
+
+
 /**
  * gtkosx_application_set_window_menu:
  * @self: The application object
