@@ -58,6 +58,7 @@
 
 #include <gtk/gtk.h>
 #include <stdio.h>
+#include <libintl.h>
 
 /* Uncomment ONE of these to test menu-mangling: */
 //#define GTKMACINTEGRATION
@@ -783,8 +784,7 @@ create_window (const gchar *title)
 #ifdef GTKOSXAPPLICATION
   GtkWidget *sep;
   gtkosx_application_set_menu_bar (theApp, GTK_MENU_SHELL (menubar));
-  gtkosx_application_insert_app_menu_item  (theApp, items->about_item,
-      0);
+  gtkosx_application_set_about_item  (theApp, items->about_item);
   sep = gtk_separator_menu_item_new ();
   g_object_ref (sep);
   gtkosx_application_insert_app_menu_item  (theApp, sep, 1);
@@ -818,6 +818,9 @@ main (int argc, char **argv)
 #ifdef GTKOSXAPPLICATION
   GtkosxApplication *theApp;
 #endif //GTKOSXAPPLICATION
+  setlocale (LC_ALL, "");
+  bindtextdomain (PACKAGE_NAME, LOCALEDIR);
+  textdomain (PACKAGE_NAME);
 #if ! GLIB_CHECK_VERSION (2, 34, 0)
   g_thread_init (NULL);
 #endif
